#include <libnd.h>
#include <libnd_ta.h>

const char *
name(void)
{
  return "Traffic-Analyzer-Test";
}

gboolean
run(LND_Trace *unused, LND_PluginArgs *args)
{
  int i;
  char  filename[MAXPATHLEN];
  FILE *output;
  LND_Trace *trace;
  LND_TAnalysis *ta;

  if (!args)
    return FALSE;

  if (args->argc == 0)
    {
      printf("Please provide one or more traces to scan.\n");
      return FALSE;
    }

  ta = libnd_ta_new();
  
  for (i = 0; i < args->argc; i++)
    {
      printf("Scanning file %s\n", args->argv[i]);
      
      if (! (trace = libnd_trace_new(args->argv[i])))
	{
	  printf("Could not open %s, skipping.\n", args->argv[i]);
	  continue;
	}
      
      libnd_ta_add_trace(ta, trace);
    }

  libnd_ta_analyze(ta);
  
  g_snprintf(filename, MAXPATHLEN, "%s.stats.txt", args->argv[0]);
  if (! (output = fopen(filename, "w")))
    {
      printf("Could not create output file %s\n", filename);
      libnd_ta_free(ta);
      return FALSE;
    }
  
  printf("Writing results to %s\n", filename);
  libnd_ta_write_results(ta, output);
  fclose(output);
  libnd_ta_free(ta);

  return TRUE;
}

